==> 0.0.13.tar.gz: ios/Classes/AntsomiPlugin.swift <==
import Flutter
import UIKit
import os.log
import AntsomiFramework

public class AntsomiPlugin: NSObject, FlutterPlugin {
    public var antsomiUNUserNotificationCenter = AntsomiUNUserNotificationCenter()
    private var _appInbox: AppInbox!
    private var _appInboxMessage: [InboxItem] = []
    private var _socketListener: ((Bool) -> Void)?
    private static var channel : FlutterMethodChannel?
    
    
    public func application(_ application: UIApplication, didFinishLaunchingWithOptions launchOptions: [AnyHashable : Any] = [:]) -> Bool {
        let center = UNUserNotificationCenter.current()
        center.requestAuthorization(options: [.alert, .sound, .badge]) { granted, error in
            
            if let error = error {
                Antsomi.shared.log(error.localizedDescription)
            }
            DispatchQueue.main.async {
                UIApplication.shared.registerForRemoteNotifications()
            }
            
        }
        UNUserNotificationCenter.current().delegate = antsomiUNUserNotificationCenter
        configureNotificationActions()
        return true
    }
    
    public func application(_ application: UIApplication, didRegisterForRemoteNotificationsWithDeviceToken deviceToken: Data) {
        print(deviceToken)
        Antsomi.shared.registerForNotification(deviceToken)
    }
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        channel = FlutterMethodChannel(name: "antsomi", binaryMessenger: registrar.messenger())
        let instance = AntsomiPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel!)
        registrar.addApplicationDelegate(instance)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
        case "getPlatformVersion":
            result("iOS " + UIDevice.current.systemVersion)
        case "setCustomerProperties":
            if let arguments = call.arguments as? [String:Any], let customerId = arguments["customerId"] as? String{
                if let customerPropeties = arguments["customerProperties"] as? [String:Any] , customerPropeties.count != 0 {
                    Antsomi.shared.setCustomerProperties(customerId: customerId,customerProperties: customerPropeties)
                }
                else{
                    Antsomi.shared.setCustomerProperties(customerId: customerId)
                }
            }
        case "config":
            if let arguments = call.arguments as? [String:Any], let portalId = arguments["portalId"] as? String,
               let propsId = arguments["propsId"] as? String,
               let appGroupId = arguments["appGroupId"] as? String,
               let applicationId = arguments["applicationId"] as? String{
                let config = Antsomi.Configuration(portalId: portalId, propsId: propsId, appGroupId: appGroupId,applicationId: applicationId)
                Antsomi.shared.activate(with: config)
                Antsomi.shared.isDelivery = false
//                Antsomi.shared.logger = { str in
//                    DispatchQueue.main.async {
//                        NSLog( "<ANTSOMI> \(str)") }}
                
                result(true)
            }
            else{
                result(false)
            }
            
        case "appInboxInit":
            if let arguments = call.arguments as? [String:Any], let destinationId = arguments["destinationId"] as? String, let audienceType = arguments["audienceType"] as? String {
                Antsomi.shared.appInboxInit(destinationId: destinationId, audienceType: audienceType)
                _appInbox = Antsomi.appInbox
                _appInbox.delegate = self
            }
        case "trackAppLaunch":
            Antsomi.shared.trackAppLaunch()
        case "getUID":
            result(Antsomi.shared.getUid())
        case "getDeviceId":
            result(Antsomi.shared.getDeviceId())
            
        case "getMessage":
            if let arguments = call.arguments as? [String:Any], let catalogId = arguments["catalogId"] as? [String], let page = arguments["page"] as? Int{
                if(catalogId.count == 0){
                    Antsomi.appInbox.forceFetchInboxItem(page: page,completion: { 
                        dataDecode in
                        
                        if let data = dataDecode as? [InboxItem] {
                            let messageData = self._getMessageMap(message: data)
                        result(messageData)
                    }})
                }
                else{
                    Antsomi.appInbox.forceFetchInboxItem(
                        catalogId: catalogId,
                        page: page ,
                        completion: { dataDecode in
                            if let data = dataDecode as? [InboxItem] {
                                let messageData = self._getMessageMap(message: data)
                                result(messageData)
                            }})
                }
            }
        case "getUnreadMessageCount":
            Antsomi.appInbox.countUnreadMessage(){ countResult in
                result(countResult)
            }
            
        case "modifyAction":
            if let arguments = call.arguments as? [String:Any], let messageId = arguments["messageId"] as? [String], let action = arguments["action"] as? Int
            {
                if(action == ModifyAction.read.rawValue){
                    _appInbox.modifyMessageStatus(messageId,action:ModifyAction.read)
                }
                else{
                    _appInbox.modifyMessageStatus(messageId,action: ModifyAction.unread)
                }
            }
        case "parseDeepLink":
            if let arguments = call.arguments as? [String:Any], let urlDeepLink = arguments["url"] as? String{
                Antsomi.shared.handleDeeplinkURL(URL(string:urlDeepLink)!)
            }
        case "setPageLimit":
            if let arguments = call.arguments as? [String:Any], let limit = arguments["limit"] as? Int {
                guard Antsomi.appInbox != nil else {return}
                AppInbox.setPageLimit(pageLimit: limit)
            }
        case "getPropsId":
            result(Antsomi.shared.getPropsId())
        case "getPortalId":
            result(Antsomi.shared.getPortalId())
            
        case "getCustomerId":
            result(Antsomi.shared.getCustomerId())
            
        case "getAllLabels":
            Antsomi.appInbox.fetchAllCatalog { catalogs in
                var jsonArray : [String] = [String]()
                if catalogs.count != 0 {
                    
                    catalogs.forEach { item in
                        do {
                            let json = try item.jsonString() ?? ""
                            jsonArray.append(json)
                        }catch{
                            print("DECODE ERROR")
                        }
                    }
                }

                result(jsonArray)
            }
            
        case "getMessageById":
            if let arguments = call.arguments as? [String:Any], let messageId = arguments["messageId"] as? String {
                _appInbox.getMessageById(messageId: messageId) { [weak self] item in
                    do {
                        let data = try item.jsonData()
                        result(data)
                    }catch{
                        Antsomi.shared.log("[PLATFORM ERROR]: GET MESSAGE BY ID HAS OCCURS ERROR")
                    }
                }
            }
            
        case "track":
            if let arguments = call.arguments as? [String:Any], let eventFlutter = arguments["event"] as? [String : Any] {
                var event = CDPEvent()
                if let eventName =  eventFlutter["en"] as? String{
                    event.setEventName(eventName: eventName)
                }
                
                if let items = eventFlutter["items"] as? [[String:Any]] {
                    event.setItems(items: items)
                }
                if let items = eventFlutter["items"] as? [[String:Any]] {
                    print("[HM]: \(items)")
                }
                
                if let userPropperties = eventFlutter["userProps"] as? [String : Any]{
                    
                    event.setUserPropperties(userPropperties: userPropperties)
                }
                
                if let objectProperties = eventFlutter["objectProps"] as? [String : Any] {
                    print("[HM] \(objectProperties)")
                    event.setObjectProperties(objectProperties: objectProperties)
                }
                
                if let eventProperties = eventFlutter["eventProps"] as? [String : Any] {
                    event.setEventProperties(eventProperties: eventProperties)
                }
                
                if let customerProperties = eventFlutter["customerProps"] as? [String : Any] {
                    if customerProperties.count != 0 {
                        event.setCustomerProperties(customerProperties: customerProperties)
                    }
                }
                
                
                Antsomi.shared.track(event: event)
                
                
            }
        case "trackScreen":
            var title: String = ""
            var type: String = ""
            if let arguments = call.arguments as? [String:Any], let name = arguments["name"] as? String {
                if let titleArg = arguments["title"] as? String {
                    title = titleArg
                }
                if let typeArg = arguments["type"] as? String {
                    type = typeArg
                }
                Antsomi.shared.trackScreen(name: name,title: title, type : type)
            }
            
        case "isDelivery":
            result(Antsomi.shared.isDelivery)
        case "setIsDelivery":
            if let arguments = call.arguments as? [String:Any], let value = arguments["value"] as? Bool {
                Antsomi.shared.setIsDelivery(newValue: value)
            }
            
        default:
            result(FlutterMethodNotImplemented)
        }
    }
    private func configureNotificationActions() {
        antsomiUNUserNotificationCenter.setActionForUrl { urlStr in
            Antsomi.shared.handleDeeplinkURL(URL(string: urlStr)!)
        }
    }
    
    
    ///  IN CASE DEV WANT TO HANDLE DEEPLINK
    public static func handleDeepLink(url: URL) {
        Antsomi.shared.handleDeeplinkURL(url)
        AntsomiPlugin.channel?.invokeMethod("handleDeepLink", arguments: url.absoluteString)
    }
    
    private func _sendToNewDataToFlutter(inboxItem: InboxItem) {
        do {
            let data = try inboxItem.jsonString()
            AntsomiPlugin.channel?.invokeMethod("onReceiveNewData", arguments: data)
        }catch{
            Antsomi.shared.log("PLATFORM ERROR WHILE DECODING!")
        }
       
        
    }
    
    private func _setAction(){
        AntsomiPlugin.channel?.invokeMethod("setAction",arguments: false)
    }

    private func _getMessageMap(message: [InboxItem]) -> [[String:String]] {
        var result: [[String:String]] = []
        for element in message {
            result.append(_toJsonInboxItem(inboxItem: element))
        }
        return result
    }

    private func _toJsonInboxItem(inboxItem: InboxItem) -> [String:String] {
        let encoder = JSONEncoder()
        
        do {
            let catalogs = try encoder.encode(inboxItem.catalogId)
            let catalog_ids: String = String(data: catalogs, encoding: .utf8) ?? "[]"
            
            let jsonEncode : [String:String] = [
                "button_app_url_2": inboxItem.buttonAppUrl2?.absoluteString ?? "",
                "button_app_url_1" : inboxItem.buttonAppUrl1?.absoluteString ?? "",
                "content" : inboxItem.content as String,
                "last_updated": inboxItem.lastUpdated as String,
                "app_url" : inboxItem.appUrl?.absoluteString ?? "",
                "item_id": inboxItem.itemId as String,
                "heading": inboxItem.heading as String,
                "date_created" : inboxItem.dateCreated as String,
                "image_url" : inboxItem.imageUrl?.absoluteString ?? "",
                "button_label_1" : inboxItem.buttonLabel1 ?? "",
                "button_label_2" : inboxItem.buttonLabel2 ?? "",
                "launch_url" : inboxItem.lauchUrl?.absoluteString ?? "",
                "button_launch_url_1" : inboxItem.buttonLaunchUrl1?.absoluteString ?? "",
                "button_launch_url_2" : inboxItem.buttonLaunchUrl2?.absoluteString ?? "",
                "lookup_type" : inboxItem.lookupType as String,
                "template_id" : inboxItem.templateId as String,
                "status" : String(inboxItem.status),
                "tracking_url": inboxItem.trackingUrl?.absoluteString ?? "",
                "catalog_ids" : catalog_ids
            ]
            return jsonEncode
        }catch{
            print("DECODE ERROR")
        }
        
        return [:]
    }
}

extension AntsomiPlugin: AppInboxDelegate {
    public func onNewMessage(_ newMessageReceived: InboxItem) {
            self._sendToNewDataToFlutter(inboxItem: newMessageReceived)
    }
}

==> 0.0.15.tar.gz: ios/Classes/AntsomiPlugin.swift <==
import Flutter
import UIKit
import os.log
import AntsomiFramework

public class AntsomiPlugin: NSObject, FlutterPlugin {
    public var antsomiUNUserNotificationCenter = AntsomiUNUserNotificationCenter()
    private var _appInbox: AppInbox!
    private var _appInboxMessage: [InboxItem] = []
    private var _socketListener: ((Bool) -> Void)?
    private static var channel : FlutterMethodChannel?
    
    
    public func application(_ application: UIApplication, didFinishLaunchingWithOptions launchOptions: [AnyHashable : Any] = [:]) -> Bool {
        let center = UNUserNotificationCenter.current()
        center.requestAuthorization(options: [.alert, .sound, .badge]) { granted, error in
            
            if let error = error {
                Antsomi.shared.log(error.localizedDescription)
            }
            DispatchQueue.main.async {
                UIApplication.shared.registerForRemoteNotifications()
            }
            
        }
        UNUserNotificationCenter.current().delegate = antsomiUNUserNotificationCenter
        configureNotificationActions()
        return true
    }
    
    public func application(_ application: UIApplication, didRegisterForRemoteNotificationsWithDeviceToken deviceToken: Data) {
        print(deviceToken)
        Antsomi.shared.registerForNotification(deviceToken)
    }
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        channel = FlutterMethodChannel(name: "antsomi", binaryMessenger: registrar.messenger())
        let instance = AntsomiPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel!)
        registrar.addApplicationDelegate(instance)
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        switch call.method {
        case "getPlatformVersion":
            result("iOS " + UIDevice.current.systemVersion)
        case "setCustomerProperties":
            if let arguments = call.arguments as? [String:Any], let customerId = arguments["customerId"] as? String{
                if let customerPropeties = arguments["customerProperties"] as? [String:Any] , customerPropeties.count != 0 {
                    Antsomi.shared.setCustomerProperties(customerId: customerId,customerProperties: customerPropeties)
                }
                else{
                    Antsomi.shared.setCustomerProperties(customerId: customerId)
                }
            }
        case "config":
            if let arguments = call.arguments as? [String:Any], let portalId = arguments["portalId"] as? String,
               let propsId = arguments["propsId"] as? String,
               let appGroupId = arguments["appGroupId"] as? String,
               let applicationId = arguments["applicationId"] as? String{
                let config = Antsomi.Configuration(portalId: portalId, propsId: propsId, appGroupId: appGroupId,applicationId: applicationId)
                Antsomi.shared.activate(with: config)
                Antsomi.shared.isDelivery = false
                Antsomi.shared.logger = { str in
                    DispatchQueue.main.async {
                        NSLog( "<ANTSOMI> \(str)") }}
                
                result(true)
            }
            else{
                result(false)
            }
            
        case "appInboxInit":
            if let arguments = call.arguments as? [String:Any], let destinationId = arguments["destinationId"] as? String, let audienceType = arguments["audienceType"] as? String {
                Antsomi.shared.appInboxInit(destinationId: destinationId, audienceType: audienceType)
                _appInbox = Antsomi.appInbox
                _appInbox.delegate = self
            }
        case "trackAppLaunch":
            Antsomi.shared.trackAppLaunch()
        case "getUID":
            result(Antsomi.shared.getUid())
        case "getDeviceId":
            result(Antsomi.shared.getDeviceId())
            
        case "getMessage":
            if let arguments = call.arguments as? [String:Any], let catalogId = arguments["catalogId"] as? [String], let page = arguments["page"] as? Int{
                if(catalogId.count == 0){
                    Antsomi.appInbox.forceFetchInboxItem(page: page,completion: { 
                        dataDecode in
                        
                        if let data = dataDecode as? [InboxItem] {
                            let messageData = self._getMessageMap(message: data)
                        result(messageData)
                    }})
                }
                else{
                    Antsomi.appInbox.forceFetchInboxItem(
                        catalogId: catalogId,
                        page: page ,
                        completion: { dataDecode in
                            if let data = dataDecode as? [InboxItem] {
                                let messageData = self._getMessageMap(message: data)
                                result(messageData)
                            }})
                }
            }
        case "getUnreadMessageCount":
            Antsomi.appInbox.countUnreadMessage(){ countResult in
                result(countResult)
            }
            
        case "modifyAction":
            if let arguments = call.arguments as? [String:Any], let messageId = arguments["messageId"] as? [String], let action = arguments["action"] as? Int
            {
                if(action == ModifyAction.read.rawValue){
                    _appInbox.modifyMessageStatus(messageId,action:ModifyAction.read)
                }
                else if (action == ModifyAction.remove.rawValue) {
                    _appInbox.modifyMessageStatus(messageId,action: ModifyAction.remove)
                }
            }
        case "parseDeepLink":
            if let arguments = call.arguments as? [String:Any], let urlDeepLink = arguments["url"] as? String{
                Antsomi.shared.handleDeeplinkURL(URL(string:urlDeepLink)!)
            }
        case "setPageLimit":
            if let arguments = call.arguments as? [String:Any], let limit = arguments["limit"] as? Int {
                guard Antsomi.appInbox != nil else {return}
                AppInbox.setPageLimit(pageLimit: limit)
            }
        case "getPropsId":
            result(Antsomi.shared.getPropsId())
        case "getPortalId":
            result(Antsomi.shared.getPortalId())
            
        case "getCustomerId":
            result(Antsomi.shared.getCustomerId())
            
        case "getAllLabels":
            Antsomi.appInbox.fetchAllCatalog { catalogs in
                var jsonArray : [String] = [String]()
                if catalogs.count != 0 {
                    
                    catalogs.forEach { item in
                        do {
                            let json = try item.jsonString() ?? ""
                            jsonArray.append(json)
                        }catch{
                            print("DECODE ERROR")
                        }
                    }
                }

                result(jsonArray)
            }
            
        case "getMessageById":
            if let arguments = call.arguments as? [String:Any], let messageId = arguments["messageId"] as? String {
                _appInbox.getMessageById(messageId: messageId) { [weak self] item in
                    do {
                        let data = try item.jsonData()
                        result(data)
                    }catch{
                        Antsomi.shared.log("[PLATFORM ERROR]: GET MESSAGE BY ID HAS OCCURS ERROR")
                    }
                }
            }
            
        case "track":
            if let arguments = call.arguments as? [String:Any], let eventFlutter = arguments["event"] as? [String : Any] {
                var event = CDPEvent()
                if let eventName =  eventFlutter["en"] as? String{
                    event.setEventName(eventName: eventName)
                }
                
                if let items = eventFlutter["items"] as? [[String:Any]] {
                    event.setItems(items: items)
                }
                if let items = eventFlutter["items"] as? [[String:Any]] {
                    print("[HM]: \(items)")
                }
                
                if let userPropperties = eventFlutter["userProps"] as? [String : Any]{
                    
                    event.setUserPropperties(userPropperties: userPropperties)
                }
                
                if let objectProperties = eventFlutter["objectProps"] as? [String : Any] {
                    print("[HM] \(objectProperties)")
                    event.setObjectProperties(objectProperties: objectProperties)
                }
                
                if let eventProperties = eventFlutter["eventProps"] as? [String : Any] {
                    event.setEventProperties(eventProperties: eventProperties)
                }
                
                if let customerProperties = eventFlutter["customerProps"] as? [String : Any] {
                    if customerProperties.count != 0 {
                        event.setCustomerProperties(customerProperties: customerProperties)
                    }
                }
                
                
                Antsomi.shared.track(event: event)
                
                
            }
        case "trackScreen":
            var title: String = ""
            var type: String = ""
            if let arguments = call.arguments as? [String:Any], let name = arguments["name"] as? String {
                if let titleArg = arguments["title"] as? String {
                    title = titleArg
                }
                if let typeArg = arguments["type"] as? String {
                    type = typeArg
                }
                Antsomi.shared.trackScreen(name: name,title: title, type : type)
            }
            
        case "isDelivery":
            result(Antsomi.shared.isDelivery)
        case "setIsDelivery":
            if let arguments = call.arguments as? [String:Any], let value = arguments["value"] as? Bool {
                Antsomi.shared.setIsDelivery(newValue: value)
            }
        case "handleTrackingUrl":
            if let arguments = call.arguments as? [String:Any], let url = arguments["trackingUrl"] as? String {
                
                func completion() -> Void {}
                
                Antsomi.shared.handleTrackingURL(URL(string: url)!, completion: completion)
            }
            
        default:
            result(FlutterMethodNotImplemented)
        }
    }
    private func configureNotificationActions() {
        antsomiUNUserNotificationCenter.setActionForUrl { urlStr in
            Antsomi.shared.handleDeeplinkURL(URL(string: urlStr)!)
        }
    }
    
    
    ///  IN CASE DEV WANT TO HANDLE DEEPLINK
    public static func handleDeepLink(url: URL) {
        Antsomi.shared.handleDeeplinkURL(url)
        AntsomiPlugin.channel?.invokeMethod("handleDeepLink", arguments: url.absoluteString)
    }
    
    private func _sendToNewDataToFlutter(inboxItem: InboxItem) {
        do {
            let data = try inboxItem.jsonString()
            AntsomiPlugin.channel?.invokeMethod("onReceiveNewData", arguments: data)
        }catch{
            Antsomi.shared.log("PLATFORM ERROR WHILE DECODING!")
        }
       
        
    }
    
    private func _setAction(){
        AntsomiPlugin.channel?.invokeMethod("setAction",arguments: false)
    }

    private func _getMessageMap(message: [InboxItem]) -> [[String:String]] {
        var result: [[String:String]] = []
        for element in message {
            result.append(_toJsonInboxItem(inboxItem: element))
        }
        return result
    }

    private func _toJsonInboxItem(inboxItem: InboxItem) -> [String:String] {
        let encoder = JSONEncoder()
        
        do {
            let catalogs = try encoder.encode(inboxItem.catalogId)
            let catalog_ids: String = String(data: catalogs, encoding: .utf8) ?? "[]"
            
            let jsonEncode : [String:String] = [
                "button_app_url_2": inboxItem.buttonAppUrl2?.absoluteString ?? "",
                "button_app_url_1" : inboxItem.buttonAppUrl1?.absoluteString ?? "",
                "content" : inboxItem.content as String,
                "last_updated": inboxItem.lastUpdated as String,
                "app_url" : inboxItem.appUrl?.absoluteString ?? "",
                "item_id": inboxItem.itemId as String,
                "heading": inboxItem.heading as String,
                "date_created" : inboxItem.dateCreated as String,
                "image_url" : inboxItem.imageUrl?.absoluteString ?? "",
                "button_label_1" : inboxItem.buttonLabel1 ?? "",
                "button_label_2" : inboxItem.buttonLabel2 ?? "",
                "launch_url" : inboxItem.lauchUrl?.absoluteString ?? "",
                "button_launch_url_1" : inboxItem.buttonLaunchUrl1?.absoluteString ?? "",
                "button_launch_url_2" : inboxItem.buttonLaunchUrl2?.absoluteString ?? "",
                "lookup_type" : inboxItem.lookupType as String,
                "template_id" : inboxItem.templateId as String,
                "status" : String(inboxItem.status),
                "tracking_url": inboxItem.trackingUrl?.absoluteString ?? "",
                "catalog_ids" : catalog_ids
            ]
            return jsonEncode
        }catch{
            print("DECODE ERROR")
        }
        
        return [:]
    }
}

extension AntsomiPlugin: AppInboxDelegate {
    public func onNewMessage(_ newMessageReceived: InboxItem) {
            self._sendToNewDataToFlutter(inboxItem: newMessageReceived)
    }
}
